@@ -20,11 +20,13 @@
 #ifndef KFILEITEMMODELROLESUPDATER_H
 #define KFILEITEMMODELROLESUPDATER_H
 
-#include <libdolphin_export.h>
+#include <config-nepomuk.h>
 
 #include <KFileItem>
 #include <kitemviews/kitemmodelbase.h>
 
+#include <libdolphin_export.h>
+
 #include <QObject>
 #include <QSet>
 #include <QSize>
@@ -35,6 +37,21 @@ class KJob;
 class QPixmap;
 class QTimer;
 
+#ifdef HAVE_NEPOMUK
+    namespace Nepomuk
+    {
+        class ResourceWatcher;
+        class Resource;
+    }
+#else
+    // Required for the slot applyChangedNepomukRoles() that
+    // cannot be ifdefined due to moc.
+    namespace Nepomuk
+    {
+        class Resource;
+    }
+#endif
+
 /**
  * @brief Resolves expensive roles asynchronously and applies them to the KFileItemModel.
  *
@@ -111,6 +128,8 @@ private slots:
     void slotItemsRemoved(const KItemRangeList& itemRanges);
     void slotItemsChanged(const KItemRangeList& itemRanges,
                           const QSet<QByteArray>& roles);
+    void slotSortRoleChanged(const QByteArray& current,
+                             const QByteArray& previous);
 
     /**
      * Is invoked after a preview has been received successfully.
@@ -140,6 +159,8 @@ private slots:
      */
     void resolveChangedItems();
 
+    void applyChangedNepomukRoles(const Nepomuk::Resource& resource);
+
 private:
     /**
      * Updates the roles for the given item ranges. The roles for the currently
@@ -161,6 +182,22 @@ private:
     void resetPendingRoles();
     void sortAndResolveAllRoles();
     void sortAndResolvePendingRoles();
+    void applySortProgressToModel();
+
+    /**
+     * Updates m_sortProgress to be 0 if the sort-role
+     * needs to get resolved asynchronously and hence a
+     * progress is required. Otherwise m_sortProgress
+     * will be set to -1 which means that no progress
+     * will be provided.
+     */
+    void updateSortProgress();
+
+    /**
+     * @return True, if at least one item from the model
+     *         has an unknown MIME-type.
+     */
+    bool hasUnknownMimeTypes() const;
 
     enum ResolveHint {
         ResolveFast,
@@ -203,11 +240,14 @@ private:
     // during the roles-updater has been paused by setPaused().
     bool m_clearPreviews;
 
+    int m_sortingProgress;
+
     KFileItemModel* m_model;
     QSize m_iconSize;
     int m_firstVisibleIndex;
     int m_lastVisibleIndex;
     QSet<QByteArray> m_roles;
+    QSet<QByteArray> m_resolvableRoles;
     QStringList m_enabledPlugins;
 
     QSet<KFileItem> m_pendingVisibleItems;
@@ -221,6 +261,11 @@ private:
     // of time.
     QTimer* m_changedItemsTimer;
     QSet<KFileItem> m_changedItems;
+
+#ifdef HAVE_NEPOMUK
+    Nepomuk::ResourceWatcher* m_nepomukResourceWatcher;
+    mutable QHash<QUrl, KUrl> m_nepomukUriItems;
+#endif
 };
 
 #endif
