@@ -73,7 +73,7 @@ namespace {
 
 PlacesItemModel::PlacesItemModel(QObject* parent) :
     KStandardItemModel(parent),
-    m_nepomukRunning(false),
+    m_fileIndexingEnabled(false),
     m_hiddenItemsShown(false),
     m_availableDevices(),
     m_predicate(),
@@ -83,10 +83,15 @@ PlacesItemModel::PlacesItemModel(QObject* parent) :
     m_bookmarkedItems(),
     m_hiddenItemToRemove(-1),
     m_saveBookmarksTimer(0),
-    m_updateBookmarksTimer(0)
+    m_updateBookmarksTimer(0),
+    m_storageSetupInProgress()
 {
 #ifdef HAVE_NEPOMUK
-    m_nepomukRunning = (Nepomuk::ResourceManager::instance()->initialized());
+    if (Nepomuk::ResourceManager::instance()->initialized()) {
+        KConfig config("nepomukserverrc");
+        m_fileIndexingEnabled = config.group("Service-nepomukfileindexer").readEntry("autostart", false);
+    }
+
 #endif
     const QString file = KStandardDirs::locateLocal("data", "kfileplaces/bookmarks.xml");
     m_bookmarkManager = KBookmarkManager::managerForFile(file, "kfilePlaces");
@@ -226,6 +231,32 @@ int PlacesItemModel::closestItem(const KUrl& url) const
     return foundIndex;
 }
 
+void PlacesItemModel::appendItemToGroup(PlacesItem* item)
+{
+    if (!item) {
+        return;
+    }
+
+    int i = 0;
+    while (i < count() && placesItem(i)->group() != item->group()) {
+        ++i;
+    }
+
+    bool inserted = false;
+    while (!inserted && i < count()) {
+        if (placesItem(i)->group() != item->group()) {
+            insertItem(i, item);
+            inserted = true;
+        }
+        ++i;
+    }
+
+    if (!inserted) {
+        appendItem(item);
+    }
+}
+
+
 QAction* PlacesItemModel::ejectAction(int index) const
 {
     const PlacesItem* item = placesItem(index);
@@ -312,6 +343,35 @@ void PlacesItemModel::requestTeardown(int index)
     }
 }
 
+bool PlacesItemModel::storageSetupNeeded(int index) const
+{
+    const PlacesItem* item = placesItem(index);
+    return item ? item->storageSetupNeeded() : false;
+}
+
+void PlacesItemModel::requestStorageSetup(int index)
+{
+    const PlacesItem* item = placesItem(index);
+    if (!item) {
+        return;
+    }
+
+    Solid::Device device = item->device();
+    const bool setup = device.is<Solid::StorageAccess>()
+                       && !m_storageSetupInProgress.contains(device.as<Solid::StorageAccess>())
+                       && !device.as<Solid::StorageAccess>()->isAccessible();
+    if (setup) {
+        Solid::StorageAccess* access = device.as<Solid::StorageAccess>();
+
+        m_storageSetupInProgress[access] = index;
+
+        connect(access, SIGNAL(setupDone(Solid::ErrorType,QVariant,QString)),
+                this, SLOT(slotStorageSetupDone(Solid::ErrorType,QVariant,QString)));
+
+        access->setup();
+    }
+}
+
 QMimeData* PlacesItemModel::createMimeData(const QSet<int>& indexes) const
 {
     KUrl::List urls;
@@ -344,6 +404,10 @@ void PlacesItemModel::dropMimeData(int index, const QMimeData* mimeData)
         QDataStream stream(&itemData, QIODevice::ReadOnly);
         int oldIndex;
         stream >> oldIndex;
+        if (oldIndex == index || oldIndex == index - 1) {
+            // No moving has been done
+            return;
+        }
 
         PlacesItem* oldItem = placesItem(oldIndex);
         if (!oldItem) {
@@ -353,7 +417,7 @@ void PlacesItemModel::dropMimeData(int index, const QMimeData* mimeData)
         PlacesItem* newItem = new PlacesItem(oldItem->bookmark());
         removeItem(oldIndex);
 
-        if (oldIndex <= index) {
+        if (oldIndex < index) {
             --index;
         }
 
@@ -370,11 +434,7 @@ void PlacesItemModel::dropMimeData(int index, const QMimeData* mimeData)
                 text = url.host();
             }
 
-            KBookmark bookmark = PlacesItem::createBookmark(m_bookmarkManager,
-                                                            text,
-                                                            url,
-                                                            "folder");
-            PlacesItem* newItem = new PlacesItem(bookmark);
+            PlacesItem* newItem = createPlacesItem(text, url);
             const int dropIndex = groupedDropIndex(index, newItem);
             insertItem(dropIndex, newItem);
         }
@@ -526,6 +586,37 @@ void PlacesItemModel::slotStorageTeardownDone(Solid::ErrorType error, const QVar
     }
 }
 
+void PlacesItemModel::slotStorageSetupDone(Solid::ErrorType error,
+                                           const QVariant& errorData,
+                                           const QString& udi)
+{
+    Q_UNUSED(udi);
+
+    const int index = m_storageSetupInProgress.take(sender());
+    const PlacesItem*  item = placesItem(index);
+    if (!item) {
+        return;
+    }
+
+    if (error) {
+        // TODO: Request message-freeze exception
+        if (errorData.isValid()) {
+        //    emit errorMessage(i18nc("@info", "An error occurred while accessing '%1', the system responded: %2",
+        //                            item->text(),
+        //                            errorData.toString()));
+            emit errorMessage(QString("An error occurred while accessing '%1', the system responded: %2")
+                              .arg(item->text()).arg(errorData.toString()));
+        } else {
+        //    emit errorMessage(i18nc("@info", "An error occurred while accessing '%1'",
+        //                            item->text()));
+            emit errorMessage(QString("An error occurred while accessing '%1'").arg(item->text()));
+        }
+        emit storageSetupDone(index, false);
+    } else {
+        emit storageSetupDone(index, true);
+    }
+}
+
 void PlacesItemModel::hideItem()
 {
     hideItem(m_hiddenItemToRemove);
@@ -539,7 +630,7 @@ void PlacesItemModel::updateBookmarks()
     KBookmarkGroup root = m_bookmarkManager->root();
     KBookmark newBookmark = root.first();
     while (!newBookmark.isNull()) {
-        if (acceptBookmark(newBookmark)) {
+        if (acceptBookmark(newBookmark, m_availableDevices)) {
             bool found = false;
             int modelIndex = 0;
             for (int i = 0; i < m_bookmarkedItems.count(); ++i) {
@@ -567,7 +658,7 @@ void PlacesItemModel::updateBookmarks()
                 if (item->isHidden() && !m_hiddenItemsShown) {
                     m_bookmarkedItems.append(item);
                 } else {
-                    appendItem(item);
+                    appendItemToGroup(item);
                 }
             }
         }
@@ -637,7 +728,7 @@ void PlacesItemModel::loadBookmarks()
     QList<PlacesItem*> devicesItems;
 
     while (!bookmark.isNull()) {
-        if (acceptBookmark(bookmark)) {
+        if (acceptBookmark(bookmark, devices)) {
             PlacesItem* item = new PlacesItem(bookmark);
             if (item->groupType() == PlacesItem::DevicesType) {
                 devices.remove(item->udi());
@@ -710,18 +801,19 @@ void PlacesItemModel::loadBookmarks()
 #endif
 }
 
-bool PlacesItemModel::acceptBookmark(const KBookmark& bookmark) const
+bool PlacesItemModel::acceptBookmark(const KBookmark& bookmark,
+                                     const QSet<QString>& availableDevices) const
 {
     const QString udi = bookmark.metaDataItem("UDI");
     const KUrl url = bookmark.url();
     const QString appName = bookmark.metaDataItem("OnlyInApp");
-    const bool deviceAvailable = m_availableDevices.contains(udi);
+    const bool deviceAvailable = availableDevices.contains(udi);
 
     const bool allowedHere = (appName.isEmpty()
                               || appName == KGlobal::mainComponent().componentName()
                               || appName == KGlobal::mainComponent().componentName() + AppNamePrefix)
-                             && (m_nepomukRunning || (url.protocol() != QLatin1String("timeline") &&
-                                                      url.protocol() != QLatin1String("search")));
+                             && (m_fileIndexingEnabled || (url.protocol() != QLatin1String("timeline") &&
+                                                           url.protocol() != QLatin1String("search")));
 
     return (udi.isEmpty() && allowedHere) || deviceAvailable;
 }
@@ -802,7 +894,7 @@ void PlacesItemModel::createSystemBookmarks()
                                                 "user-trash",
                                                 i18nc("@item", "Trash")));
 
-    if (m_nepomukRunning) {
+    if (m_fileIndexingEnabled) {
         m_systemBookmarks.append(SystemBookmarkData(KUrl("timeline:/today"),
                                                     timeLineIcon,
                                                     i18nc("@item Recently Accessed", "Today")));
