@@ -22,6 +22,7 @@
 
 #include <KDirLister>
 #include "kitemviews/kfileitemmodel.h"
+#include "kitemviews/private/kfileitemmodeldirlister.h"
 #include "testdir.h"
 
 void myMessageOutput(QtMsgType type, const char* msg)
@@ -62,7 +63,7 @@ private slots:
     void testDefaultGroupedSorting();
     void testNewItems();
     void testRemoveItems();
-    void testLoadingCompleted();
+    void testDirLoadingCompleted();
     void testSetData();
     void testSetDataWithModifiedSortRole_data();
     void testSetDataWithModifiedSortRole();
@@ -82,7 +83,6 @@ private:
 
 private:
     KFileItemModel* m_model;
-    KDirLister* m_dirLister;
     TestDir* m_testDir;
 };
 
@@ -97,9 +97,8 @@ void KFileItemModelTest::init()
     qRegisterMetaType<KFileItemList>("KFileItemList");
 
     m_testDir = new TestDir();
-    m_dirLister = new KDirLister();
-    m_dirLister->setAutoUpdate(false);
-    m_model = new KFileItemModel(m_dirLister);
+    m_model = new KFileItemModel();
+    m_model->m_dirLister->setAutoUpdate(false);
 }
 
 void KFileItemModelTest::cleanup()
@@ -107,9 +106,6 @@ void KFileItemModelTest::cleanup()
     delete m_model;
     m_model = 0;
 
-    delete m_dirLister;
-    m_dirLister = 0;
-
     delete m_testDir;
     m_testDir = 0;
 }
@@ -117,27 +113,28 @@ void KFileItemModelTest::cleanup()
 void KFileItemModelTest::testDefaultRoles()
 {
     const QSet<QByteArray> roles = m_model->roles();
-    QCOMPARE(roles.count(), 2);
-    QVERIFY(roles.contains("name"));
+    QCOMPARE(roles.count(), 3);
+    QVERIFY(roles.contains("text"));
     QVERIFY(roles.contains("isDir"));
+    QVERIFY(roles.contains("isLink"));
 }
 
 void KFileItemModelTest::testDefaultSortRole()
 {
-    QCOMPARE(m_model->sortRole(), QByteArray("name"));
+    QCOMPARE(m_model->sortRole(), QByteArray("text"));
 
     QStringList files;
     files << "c.txt" << "a.txt" << "b.txt";
 
     m_testDir->createFiles(files);
 
-    m_dirLister->openUrl(m_testDir->url());
+    m_model->loadDirectory(m_testDir->url());
     QVERIFY(QTest::kWaitForSignal(m_model, SIGNAL(itemsInserted(KItemRangeList)), DefaultTimeout));
 
     QCOMPARE(m_model->count(), 3);
-    QCOMPARE(m_model->data(0)["name"].toString(), QString("a.txt"));
-    QCOMPARE(m_model->data(1)["name"].toString(), QString("b.txt"));
-    QCOMPARE(m_model->data(2)["name"].toString(), QString("c.txt"));
+    QCOMPARE(m_model->data(0)["text"].toString(), QString("a.txt"));
+    QCOMPARE(m_model->data(1)["text"].toString(), QString("b.txt"));
+    QCOMPARE(m_model->data(2)["text"].toString(), QString("c.txt"));
 }
 
 void KFileItemModelTest::testDefaultGroupedSorting()
@@ -151,7 +148,7 @@ void KFileItemModelTest::testNewItems()
     files << "a.txt" << "b.txt" << "c.txt";
     m_testDir->createFiles(files);
 
-    m_dirLister->openUrl(m_testDir->url());
+    m_model->loadDirectory(m_testDir->url());
     QVERIFY(QTest::kWaitForSignal(m_model, SIGNAL(itemsInserted(KItemRangeList)), DefaultTimeout));
 
     QCOMPARE(m_model->count(), 3);
@@ -163,36 +160,36 @@ void KFileItemModelTest::testRemoveItems()
 {
     m_testDir->createFile("a.txt");
     m_testDir->createFile("b.txt");
-    m_dirLister->openUrl(m_testDir->url());
+    m_model->loadDirectory(m_testDir->url());
     QVERIFY(QTest::kWaitForSignal(m_model, SIGNAL(itemsInserted(KItemRangeList)), DefaultTimeout));
     QCOMPARE(m_model->count(), 2);
     QVERIFY(isModelConsistent());
 
     m_testDir->removeFile("a.txt");
-    m_dirLister->updateDirectory(m_testDir->url());
+    m_model->m_dirLister->updateDirectory(m_testDir->url());
     QVERIFY(QTest::kWaitForSignal(m_model, SIGNAL(itemsRemoved(KItemRangeList)), DefaultTimeout));
     QCOMPARE(m_model->count(), 1);
     QVERIFY(isModelConsistent());
 }
 
-void KFileItemModelTest::testLoadingCompleted()
+void KFileItemModelTest::testDirLoadingCompleted()
 {
-    QSignalSpy loadingCompletedSpy(m_model, SIGNAL(loadingCompleted()));
+    QSignalSpy loadingCompletedSpy(m_model, SIGNAL(directoryLoadingCompleted()));
     QSignalSpy itemsInsertedSpy(m_model, SIGNAL(itemsInserted(KItemRangeList)));
     QSignalSpy itemsRemovedSpy(m_model, SIGNAL(itemsRemoved(KItemRangeList)));
 
     m_testDir->createFiles(QStringList() << "a.txt" << "b.txt" << "c.txt");
 
-    m_dirLister->openUrl(m_testDir->url());
-    QVERIFY(QTest::kWaitForSignal(m_model, SIGNAL(loadingCompleted()), DefaultTimeout));
+    m_model->loadDirectory(m_testDir->url());
+    QVERIFY(QTest::kWaitForSignal(m_model, SIGNAL(directoryLoadingCompleted()), DefaultTimeout));
     QCOMPARE(loadingCompletedSpy.count(), 1);
     QCOMPARE(itemsInsertedSpy.count(), 1);
     QCOMPARE(itemsRemovedSpy.count(), 0);
     QCOMPARE(m_model->count(), 3);
 
     m_testDir->createFiles(QStringList() << "d.txt" << "e.txt");
-    m_dirLister->updateDirectory(m_testDir->url());
-    QVERIFY(QTest::kWaitForSignal(m_model, SIGNAL(loadingCompleted()), DefaultTimeout));
+    m_model->m_dirLister->updateDirectory(m_testDir->url());
+    QVERIFY(QTest::kWaitForSignal(m_model, SIGNAL(directoryLoadingCompleted()), DefaultTimeout));
     QCOMPARE(loadingCompletedSpy.count(), 2);
     QCOMPARE(itemsInsertedSpy.count(), 2);
     QCOMPARE(itemsRemovedSpy.count(), 0);
@@ -200,15 +197,15 @@ void KFileItemModelTest::testLoadingCompleted()
 
     m_testDir->removeFile("a.txt");
     m_testDir->createFile("f.txt");
-    m_dirLister->updateDirectory(m_testDir->url());
-    QVERIFY(QTest::kWaitForSignal(m_model, SIGNAL(loadingCompleted()), DefaultTimeout));
+    m_model->m_dirLister->updateDirectory(m_testDir->url());
+    QVERIFY(QTest::kWaitForSignal(m_model, SIGNAL(directoryLoadingCompleted()), DefaultTimeout));
     QCOMPARE(loadingCompletedSpy.count(), 3);
     QCOMPARE(itemsInsertedSpy.count(), 3);
     QCOMPARE(itemsRemovedSpy.count(), 1);
     QCOMPARE(m_model->count(), 5);
 
     m_testDir->removeFile("b.txt");
-    m_dirLister->updateDirectory(m_testDir->url());
+    m_model->m_dirLister->updateDirectory(m_testDir->url());
     QVERIFY(QTest::kWaitForSignal(m_model, SIGNAL(itemsRemoved(KItemRangeList)), DefaultTimeout));
     QCOMPARE(loadingCompletedSpy.count(), 4);
     QCOMPARE(itemsInsertedSpy.count(), 3);
@@ -222,7 +219,7 @@ void KFileItemModelTest::testSetData()
 {
     m_testDir->createFile("a.txt");
 
-    m_dirLister->openUrl(m_testDir->url());
+    m_model->loadDirectory(m_testDir->url());
     QVERIFY(QTest::kWaitForSignal(m_model, SIGNAL(itemsInserted(KItemRangeList)), DefaultTimeout));
 
     QHash<QByteArray, QVariant> values;
@@ -273,13 +270,13 @@ void KFileItemModelTest::testSetDataWithModifiedSortRole()
 
     // Changing the value of a sort-role must result in
     // a reordering of the items.
-    QCOMPARE(m_model->sortRole(), QByteArray("name"));
+    QCOMPARE(m_model->sortRole(), QByteArray("text"));
 
     QStringList files;
     files << "a.txt" << "b.txt" << "c.txt";
     m_testDir->createFiles(files);
 
-    m_dirLister->openUrl(m_testDir->url());
+    m_model->loadDirectory(m_testDir->url());
     QVERIFY(QTest::kWaitForSignal(m_model, SIGNAL(itemsInserted(KItemRangeList)), DefaultTimeout));
 
     // Fill the "rating" role of each file:
@@ -331,7 +328,7 @@ void KFileItemModelTest::testModelConsistencyWhenInsertingItems()
     // KFileItemModel to do a lot of insert operation and hence decrease
     // the timeout to 1 millisecond.
     m_testDir->createFile("1");
-    m_dirLister->openUrl(m_testDir->url());
+    m_model->loadDirectory(m_testDir->url());
     QVERIFY(QTest::kWaitForSignal(m_model, SIGNAL(itemsInserted(KItemRangeList)), DefaultTimeout));
     QCOMPARE(m_model->count(), 1);
 
@@ -351,7 +348,7 @@ void KFileItemModelTest::testModelConsistencyWhenInsertingItems()
             m_testDir->createFile(QString::number(itemName));
         }
 
-        m_dirLister->updateDirectory(m_testDir->url());
+        m_model->m_dirLister->updateDirectory(m_testDir->url());
         if (spy.count() == 0) {
             QVERIFY(QTest::kWaitForSignal(m_model, SIGNAL(itemsInserted(KItemRangeList)), DefaultTimeout));
         }
@@ -371,7 +368,7 @@ void KFileItemModelTest::testItemRangeConsistencyWhenInsertingItems()
     // Due to inserting the 3 items one item-range with index == 0 and
     // count == 3 must be given
     QSignalSpy spy1(m_model, SIGNAL(itemsInserted(KItemRangeList)));
-    m_dirLister->openUrl(m_testDir->url());
+    m_model->loadDirectory(m_testDir->url());
     QVERIFY(QTest::kWaitForSignal(m_model, SIGNAL(itemsInserted(KItemRangeList)), DefaultTimeout));
 
     QCOMPARE(spy1.count(), 1);
@@ -396,7 +393,7 @@ void KFileItemModelTest::testItemRangeConsistencyWhenInsertingItems()
     m_testDir->createFiles(files);
 
     QSignalSpy spy2(m_model, SIGNAL(itemsInserted(KItemRangeList)));
-    m_dirLister->updateDirectory(m_testDir->url());
+    m_model->m_dirLister->updateDirectory(m_testDir->url());
     QVERIFY(QTest::kWaitForSignal(m_model, SIGNAL(itemsInserted(KItemRangeList)), DefaultTimeout));
 
     QCOMPARE(spy2.count(), 1);
@@ -424,14 +421,14 @@ void KFileItemModelTest::testExpandItems()
     QSet<KUrl> allFolders;
     allFolders << KUrl(m_testDir->name() + "a") << KUrl(m_testDir->name() + "a/a") << KUrl(m_testDir->name() + "a/a-1");
 
-    m_dirLister->openUrl(m_testDir->url());
+    m_model->loadDirectory(m_testDir->url());
     QVERIFY(QTest::kWaitForSignal(m_model, SIGNAL(itemsInserted(KItemRangeList)), DefaultTimeout));
 
     // So far, the model contains only "a/"
     QCOMPARE(m_model->count(), 1);
     QVERIFY(m_model->isExpandable(0));
     QVERIFY(!m_model->isExpanded(0));
-    QVERIFY(m_model->expandedUrls().empty());
+    QVERIFY(m_model->expandedDirectories().empty());
 
     QSignalSpy spyInserted(m_model, SIGNAL(itemsInserted(KItemRangeList)));
 
@@ -440,7 +437,7 @@ void KFileItemModelTest::testExpandItems()
     QVERIFY(m_model->isExpanded(0));
     QVERIFY(QTest::kWaitForSignal(m_model, SIGNAL(itemsInserted(KItemRangeList)), DefaultTimeout));
     QCOMPARE(m_model->count(), 3); // 3 items: "a/", "a/a/", "a/a-1/"
-    QCOMPARE(m_model->expandedUrls(), QSet<KUrl>() << KUrl(m_testDir->name() + "a"));
+    QCOMPARE(m_model->expandedDirectories(), QSet<KUrl>() << KUrl(m_testDir->name() + "a"));
 
     QCOMPARE(spyInserted.count(), 1);
     KItemRangeList itemRangeList = spyInserted.takeFirst().at(0).value<KItemRangeList>();
@@ -456,7 +453,7 @@ void KFileItemModelTest::testExpandItems()
     QVERIFY(m_model->isExpanded(1));
     QVERIFY(QTest::kWaitForSignal(m_model, SIGNAL(itemsInserted(KItemRangeList)), DefaultTimeout));
     QCOMPARE(m_model->count(), 4);  // 4 items: "a/", "a/a/", "a/a/1", "a/a-1/"
-    QCOMPARE(m_model->expandedUrls(), QSet<KUrl>() << KUrl(m_testDir->name() + "a") << KUrl(m_testDir->name() + "a/a"));
+    QCOMPARE(m_model->expandedDirectories(), QSet<KUrl>() << KUrl(m_testDir->name() + "a") << KUrl(m_testDir->name() + "a/a"));
 
     QCOMPARE(spyInserted.count(), 1);
     itemRangeList = spyInserted.takeFirst().at(0).value<KItemRangeList>();
@@ -470,7 +467,7 @@ void KFileItemModelTest::testExpandItems()
     QVERIFY(m_model->isExpanded(3));
     QVERIFY(QTest::kWaitForSignal(m_model, SIGNAL(itemsInserted(KItemRangeList)), DefaultTimeout));
     QCOMPARE(m_model->count(), 5);  // 5 items: "a/", "a/a/", "a/a/1", "a/a-1/", "a/a-1/1"
-    QCOMPARE(m_model->expandedUrls(), allFolders);
+    QCOMPARE(m_model->expandedDirectories(), allFolders);
 
     QCOMPARE(spyInserted.count(), 1);
     itemRangeList = spyInserted.takeFirst().at(0).value<KItemRangeList>();
@@ -485,7 +482,7 @@ void KFileItemModelTest::testExpandItems()
     m_model->setExpanded(0, false);
     QVERIFY(!m_model->isExpanded(0));
     QCOMPARE(m_model->count(), 1);
-    QVERIFY(!m_model->expandedUrls().contains(KUrl(m_testDir->name() + "a"))); // TODO: Make sure that child URLs are also removed
+    QVERIFY(!m_model->expandedDirectories().contains(KUrl(m_testDir->name() + "a"))); // TODO: Make sure that child URLs are also removed
 
     QCOMPARE(spyRemoved.count(), 1);
     itemRangeList = spyRemoved.takeFirst().at(0).value<KItemRangeList>();
@@ -494,29 +491,29 @@ void KFileItemModelTest::testExpandItems()
     // Clear the model, reload the folder and try to restore the expanded folders.
     m_model->clear();
     QCOMPARE(m_model->count(), 0);
-    QVERIFY(m_model->expandedUrls().empty());
+    QVERIFY(m_model->expandedDirectories().empty());
 
-    m_dirLister->openUrl(m_testDir->url());
-    m_model->restoreExpandedUrls(allFolders);
-    QVERIFY(QTest::kWaitForSignal(m_model, SIGNAL(loadingCompleted()), DefaultTimeout));
+    m_model->loadDirectory(m_testDir->url());
+    m_model->restoreExpandedDirectories(allFolders);
+    QVERIFY(QTest::kWaitForSignal(m_model, SIGNAL(directoryLoadingCompleted()), DefaultTimeout));
     QCOMPARE(m_model->count(), 5);  // 5 items: "a/", "a/a/", "a/a/1", "a/a-1/", "a/a-1/1"
     QVERIFY(m_model->isExpanded(0));
     QVERIFY(m_model->isExpanded(1));
     QVERIFY(!m_model->isExpanded(2));
     QVERIFY(m_model->isExpanded(3));
     QVERIFY(!m_model->isExpanded(4));
-    QCOMPARE(m_model->expandedUrls(), allFolders);
+    QCOMPARE(m_model->expandedDirectories(), allFolders);
 
     // Move to a sub folder, then call restoreExpandedFolders() *before* going back.
     // This is how DolphinView restores the expanded folders when navigating in history.
-    m_dirLister->openUrl(KUrl(m_testDir->name() + "a/a/"));
-    QVERIFY(QTest::kWaitForSignal(m_model, SIGNAL(loadingCompleted()), DefaultTimeout));
+    m_model->loadDirectory(KUrl(m_testDir->name() + "a/a/"));
+    QVERIFY(QTest::kWaitForSignal(m_model, SIGNAL(directoryLoadingCompleted()), DefaultTimeout));
     QCOMPARE(m_model->count(), 1);  // 1 item: "1"
-    m_model->restoreExpandedUrls(allFolders);
-    m_dirLister->openUrl(m_testDir->url());
-    QVERIFY(QTest::kWaitForSignal(m_model, SIGNAL(loadingCompleted()), DefaultTimeout));
+    m_model->restoreExpandedDirectories(allFolders);
+    m_model->loadDirectory(m_testDir->url());
+    QVERIFY(QTest::kWaitForSignal(m_model, SIGNAL(directoryLoadingCompleted()), DefaultTimeout));
     QCOMPARE(m_model->count(), 5);  // 5 items: "a/", "a/a/", "a/a/1", "a/a-1/", "a/a-1/1"
-    QCOMPARE(m_model->expandedUrls(), allFolders);
+    QCOMPARE(m_model->expandedDirectories(), allFolders);
 }
 
 void KFileItemModelTest::testExpandParentItems()
@@ -537,16 +534,16 @@ void KFileItemModelTest::testExpandParentItems()
     files << "a 1/b1/c1/file.txt" << "a2/b2/c2/d2/file.txt"; // missing folders are created automatically
     m_testDir->createFiles(files);
 
-    m_dirLister->openUrl(m_testDir->url());
+    m_model->loadDirectory(m_testDir->url());
     QVERIFY(QTest::kWaitForSignal(m_model, SIGNAL(itemsInserted(KItemRangeList)), DefaultTimeout));
 
     // So far, the model contains only "a 1/" and "a2/".
     QCOMPARE(m_model->count(), 2);
-    QVERIFY(m_model->expandedUrls().empty());
+    QVERIFY(m_model->expandedDirectories().empty());
 
     // Expand the parents of "a2/b2/c2".
-    m_model->expandParentItems(KUrl(m_testDir->name() + "a2/b2/c2"));
-    QVERIFY(QTest::kWaitForSignal(m_model, SIGNAL(loadingCompleted()), DefaultTimeout));
+    m_model->expandParentDirectories(KUrl(m_testDir->name() + "a2/b2/c2"));
+    QVERIFY(QTest::kWaitForSignal(m_model, SIGNAL(directoryLoadingCompleted()), DefaultTimeout));
 
     // The model should now contain "a 1/", "a2/", "a2/b2/", and "a2/b2/c2/".
     // It's important that only the parents of "a1/b1/c1" are expanded.
@@ -557,8 +554,8 @@ void KFileItemModelTest::testExpandParentItems()
     QVERIFY(!m_model->isExpanded(3));
 
     // Expand the parents of "a 1/b1".
-    m_model->expandParentItems(KUrl(m_testDir->name() + "a 1/b1"));
-    QVERIFY(QTest::kWaitForSignal(m_model, SIGNAL(loadingCompleted()), DefaultTimeout));
+    m_model->expandParentDirectories(KUrl(m_testDir->name() + "a 1/b1"));
+    QVERIFY(QTest::kWaitForSignal(m_model, SIGNAL(directoryLoadingCompleted()), DefaultTimeout));
 
     // The model should now contain "a 1/", "a 1/b1/", "a2/", "a2/b2", and "a2/b2/c2/".
     // It's important that only the parents of "a 1/b1/" and "a2/b2/c2/" are expanded.
@@ -576,7 +573,7 @@ void KFileItemModelTest::testSorting()
     QDateTime now = QDateTime::currentDateTime();
 
     QSet<QByteArray> roles;
-    roles.insert("name");
+    roles.insert("text");
     roles.insert("isExpanded");
     roles.insert("isExpandable");
     roles.insert("expandedParentsCount");
@@ -593,7 +590,7 @@ void KFileItemModelTest::testSorting()
     m_testDir->createFile("e", "An even larger file", now.addDays(-4));
     m_testDir->createFile(".f");
 
-    m_dirLister->openUrl(m_testDir->url());
+    m_model->loadDirectory(m_testDir->url());
     QVERIFY(QTest::kWaitForSignal(m_model, SIGNAL(itemsInserted(KItemRangeList)), DefaultTimeout));
 
     int index = m_model->index(KUrl(m_testDir->url().url() + "c"));
@@ -605,26 +602,26 @@ void KFileItemModelTest::testSorting()
     QVERIFY(QTest::kWaitForSignal(m_model, SIGNAL(itemsInserted(KItemRangeList)), DefaultTimeout));
 
     // Default: Sort by Name, ascending
-    QCOMPARE(m_model->sortRole(), QByteArray("name"));
+    QCOMPARE(m_model->sortRole(), QByteArray("text"));
     QCOMPARE(m_model->sortOrder(), Qt::AscendingOrder);
-    QVERIFY(m_model->sortFoldersFirst());
+    QVERIFY(m_model->sortDirectoriesFirst());
     QVERIFY(!m_model->showHiddenFiles());
     QCOMPARE(itemsInModel(), QStringList() << "c" << "c-2" << "c-3" << "c-1" << "a" << "b" << "d" << "e");
 
     QSignalSpy spyItemsMoved(m_model, SIGNAL(itemsMoved(KItemRange,QList<int>)));
 
     // Sort by Name, ascending, 'Sort Folders First' disabled
-    m_model->setSortFoldersFirst(false);
-    QCOMPARE(m_model->sortRole(), QByteArray("name"));
+    m_model->setSortDirectoriesFirst(false);
+    QCOMPARE(m_model->sortRole(), QByteArray("text"));
     QCOMPARE(m_model->sortOrder(), Qt::AscendingOrder);
     QCOMPARE(itemsInModel(), QStringList() << "a" << "b" << "c" << "c-1" << "c-2" << "c-3" << "d" << "e");
     QCOMPARE(spyItemsMoved.count(), 1);
     QCOMPARE(spyItemsMoved.takeFirst().at(1).value<QList<int> >(), QList<int>() << 2 << 4 << 5 << 3 << 0 << 1 << 6 << 7);
 
     // Sort by Name, descending
-    m_model->setSortFoldersFirst(true);
+    m_model->setSortDirectoriesFirst(true);
     m_model->setSortOrder(Qt::DescendingOrder);
-    QCOMPARE(m_model->sortRole(), QByteArray("name"));
+    QCOMPARE(m_model->sortRole(), QByteArray("text"));
     QCOMPARE(m_model->sortOrder(), Qt::DescendingOrder);
     QCOMPARE(itemsInModel(), QStringList() << "c" << "c-2" << "c-3" << "c-1" << "e" << "d" << "b" << "a");
     QCOMPARE(spyItemsMoved.count(), 2);
@@ -632,7 +629,7 @@ void KFileItemModelTest::testSorting()
     QCOMPARE(spyItemsMoved.takeFirst().at(1).value<QList<int> >(), QList<int>() << 0 << 1 << 2 << 3 << 7 << 6 << 5 << 4);
 
     // Sort by Date, descending
-    m_model->setSortFoldersFirst(true);
+    m_model->setSortDirectoriesFirst(true);
     m_model->setSortRole("date");
     QCOMPARE(m_model->sortRole(), QByteArray("date"));
     QCOMPARE(m_model->sortOrder(), Qt::DescendingOrder);
@@ -649,18 +646,18 @@ void KFileItemModelTest::testSorting()
     QCOMPARE(spyItemsMoved.takeFirst().at(1).value<QList<int> >(), QList<int>() << 0 << 1 << 2 << 3 << 7 << 6 << 5 << 4);
 
     // Sort by Date, ascending, 'Sort Folders First' disabled
-    m_model->setSortFoldersFirst(false);
+    m_model->setSortDirectoriesFirst(false);
     QCOMPARE(m_model->sortRole(), QByteArray("date"));
     QCOMPARE(m_model->sortOrder(), Qt::AscendingOrder);
-    QVERIFY(!m_model->sortFoldersFirst());
+    QVERIFY(!m_model->sortDirectoriesFirst());
     QCOMPARE(itemsInModel(), QStringList() << "e" << "a" << "c" << "c-1" << "c-2" << "c-3" << "d" << "b");
     QCOMPARE(spyItemsMoved.count(), 1);
     QCOMPARE(spyItemsMoved.takeFirst().at(1).value<QList<int> >(), QList<int>() << 2 << 4 << 5 << 3 << 0 << 1 << 6 << 7);
 
     // Sort by Name, ascending, 'Sort Folders First' disabled
-    m_model->setSortRole("name");
+    m_model->setSortRole("text");
     QCOMPARE(m_model->sortOrder(), Qt::AscendingOrder);
-    QVERIFY(!m_model->sortFoldersFirst());
+    QVERIFY(!m_model->sortDirectoriesFirst());
     QCOMPARE(itemsInModel(), QStringList() << "a" << "b" << "c" << "c-1" << "c-2" << "c-3" << "d" << "e");
     QCOMPARE(spyItemsMoved.count(), 1);
     QCOMPARE(spyItemsMoved.takeFirst().at(1).value<QList<int> >(), QList<int>() << 7 << 0 << 2 << 3 << 4 << 5 << 6 << 1);
@@ -669,7 +666,7 @@ void KFileItemModelTest::testSorting()
     m_model->setSortRole("size");
     QCOMPARE(m_model->sortRole(), QByteArray("size"));
     QCOMPARE(m_model->sortOrder(), Qt::AscendingOrder);
-    QVERIFY(!m_model->sortFoldersFirst());
+    QVERIFY(!m_model->sortDirectoriesFirst());
     QCOMPARE(itemsInModel(), QStringList() << "c" << "c-2" << "c-3" << "c-1" << "a" << "b" << "e" << "d");
     QCOMPARE(spyItemsMoved.count(), 1);
     QCOMPARE(spyItemsMoved.takeFirst().at(1).value<QList<int> >(), QList<int>() << 4 << 5 << 0 << 3 << 1 << 2 << 7 << 6);
@@ -680,10 +677,10 @@ void KFileItemModelTest::testSorting()
     // Internal note: Check comment in KFileItemModel::resortAllItems() for details.
 
     // In 'Sort by Size' mode, folders are always first -> changing 'Sort Folders First' does not resort the model
-    m_model->setSortFoldersFirst(true);
+    m_model->setSortDirectoriesFirst(true);
     QCOMPARE(m_model->sortRole(), QByteArray("size"));
     QCOMPARE(m_model->sortOrder(), Qt::AscendingOrder);
-    QVERIFY(m_model->sortFoldersFirst());
+    QVERIFY(m_model->sortDirectoriesFirst());
     QCOMPARE(itemsInModel(), QStringList() << "c" << "a" << "b" << "e" << "d");
     QCOMPARE(spyItemsMoved.count(), 0);
 
@@ -691,7 +688,7 @@ void KFileItemModelTest::testSorting()
     m_model->setSortOrder(Qt::DescendingOrder);
     QCOMPARE(m_model->sortRole(), QByteArray("size"));
     QCOMPARE(m_model->sortOrder(), Qt::DescendingOrder);
-    QVERIFY(m_model->sortFoldersFirst());
+    QVERIFY(m_model->sortDirectoriesFirst());
     QCOMPARE(itemsInModel(), QStringList() << "c" << "d" << "e" << "b" << "a");
     QCOMPARE(spyItemsMoved.count(), 1);
     QCOMPARE(spyItemsMoved.takeFirst().at(1).value<QList<int> >(), QList<int>() << 0 << 4 << 3 << 2 << 1);
@@ -705,7 +702,7 @@ void KFileItemModelTest::testIndexForKeyboardSearch()
     files << "a" << "aa" << "Image.jpg" << "Image.png" << "Text" << "Text1" << "Text2" << "Text11";
     m_testDir->createFiles(files);
 
-    m_dirLister->openUrl(m_testDir->url());
+    m_model->loadDirectory(m_testDir->url());
     QVERIFY(QTest::kWaitForSignal(m_model, SIGNAL(itemsInserted(KItemRangeList)), DefaultTimeout));
 
     // Search from index 0
@@ -755,7 +752,7 @@ void KFileItemModelTest::testNameFilter()
     files << "A1" << "A2" << "Abc" << "Bcd" << "Cde";
     m_testDir->createFiles(files);
 
-    m_dirLister->openUrl(m_testDir->url());
+    m_model->loadDirectory(m_testDir->url());
     QVERIFY(QTest::kWaitForSignal(m_model, SIGNAL(itemsInserted(KItemRangeList)), DefaultTimeout));
 
     m_model->setNameFilter("A"); // Shows A1, A2 and Abc
@@ -804,7 +801,7 @@ QStringList KFileItemModelTest::itemsInModel() const
 {
     QStringList items;
     for (int i = 0; i < m_model->count(); i++) {
-        items << m_model->data(i).value("name").toString();
+        items << m_model->data(i).value("text").toString();
     }
     return items;
 }
