@@ -39,11 +39,11 @@
 
 typedef KIO::FileUndoManager::CommandType CommandType;
 
-class DolphinDirLister;
-class DolphinItemListContainer;
+class DolphinItemListView;
 class KAction;
 class KActionCollection;
 class KFileItemModel;
+class KItemListContainer;
 class KItemModelBase;
 class KUrl;
 class ToolTipManager;
@@ -93,34 +93,6 @@ public:
         CompactView
     };
 
-    /** Defines the sort order for the items of a directory. */
-    enum Sorting
-    {
-        SortByName = 0,
-        SortBySize,
-        SortByDate,
-        SortByPermissions,
-        SortByOwner,
-        SortByGroup,
-        SortByType,
-        SortByDestination,
-        SortByPath
-    };
-
-    /** Defines the additional information shown for the items of a directory. */
-    enum AdditionalInfo
-    {
-        NoInfo = 0,
-        SizeInfo,
-        DateInfo,
-        PermissionsInfo,
-        OwnerInfo,
-        GroupInfo,
-        TypeInfo,
-        DestinationInfo,
-        PathInfo
-    };
-
     /**
      * @param url              Specifies the content which should be shown.
      * @param parent           Parent widget of the view.
@@ -182,6 +154,12 @@ public:
      */
     KFileItemList items() const;
 
+    /**
+     * @return The number of items. itemsCount() is faster in comparison
+     *         to items().count().
+     */
+    int itemsCount() const;
+
     /**
      * Returns the selected items. The list is empty if no item has been
      * selected.
@@ -212,7 +190,7 @@ public:
      * All items that match to the pattern \a pattern will get selected
      * if \a enabled is true and deselected if  \a enabled is false.
      */
-    void setItemSelectionEnabled(const QRegExp& pattern, bool enabled);
+    void selectItems(const QRegExp& pattern, bool enabled);
 
     /**
      * Sets the zoom level to \a level. It is assured that the used
@@ -222,45 +200,23 @@ public:
     void setZoomLevel(int level);
     int zoomLevel() const;
 
-    /**
-     * Returns true, if zooming in is possible. If false is returned,
-     * the maximum zooming level has been reached.
-     */
-    bool isZoomInPossible() const;
+    void setSortRole(const QByteArray& role);
+    QByteArray sortRole() const;
 
-    /**
-     * Returns true, if zooming out is possible. If false is returned,
-     * the minimum zooming level has been reached.
-     */
-    bool isZoomOutPossible() const;
-
-    /** Sets the sorting criterion (e.g., SortByName, SortBySize,...) of the items inside a directory (see DolphinView::Sorting). */
-    void setSorting(Sorting sorting);
-
-    /** Returns the sorting criterion (e.g., SortByName, SortBySize,...) of the items inside a directory (see DolphinView::Sorting). */
-    Sorting sorting() const;
-
-    /** Sets the sort order (Qt::Ascending or Qt::Descending) for the items. */
     void setSortOrder(Qt::SortOrder order);
-
-    /** Returns the currently used sort order (Qt::Ascending or Qt::Descending). */
     Qt::SortOrder sortOrder() const;
 
     /** Sets a separate sorting with folders first (true) or a mixed sorting of files and folders (false). */
     void setSortFoldersFirst(bool foldersFirst);
-
-    /** Returns if files and folders are sorted separately or not. */
     bool sortFoldersFirst() const;
 
     /** Sets the additional information which should be shown for the items. */
-    void setAdditionalInfoList(const QList<AdditionalInfo>& info);
+    void setVisibleRoles(const QList<QByteArray>& roles);
 
     /** Returns the additional information which should be shown for the items. */
-    QList<AdditionalInfo> additionalInfoList() const;
+    QList<QByteArray> visibleRoles() const;
 
-    /** Reloads the current directory. */
     void reload();
-
     void stopLoading();
 
     /**
@@ -281,16 +237,6 @@ public:
     void setNameFilter(const QString& nameFilter);
     QString nameFilter() const;
 
-    /**
-     * Calculates the number of currently shown files into
-     * \a fileCount and the number of folders into \a folderCount.
-     * The size of all files is written into \a totalFileSize.
-     * It is recommend using this method instead of asking the
-     * directory lister or the model directly, as it takes
-     * filtering and hierarchical previews into account.
-     */
-    void calculateItemCount(int& fileCount, int& folderCount, KIO::filesize_t& totalFileSize) const;
-
     /**
      * Returns a textual representation of the state of the current
      * folder or selected items, suitable for use in the status bar.
@@ -335,14 +281,21 @@ public:
      */
     void saveState(QDataStream& stream);
 
-    /** Returns true, if at least one item is selected. */
-    bool hasSelection() const;
-
     /**
      * Returns the root item which represents the current URL.
      */
     KFileItem rootItem() const;
 
+    /**
+     * Sets a context that is used for remembering the view-properties.
+     * Per default the context is empty and the path of the currently set URL
+     * is used for remembering the view-properties. Setting a custom context
+     * makes sense if specific types of URLs (e.g. search-URLs) should
+     * share common view-properties.
+     */
+    void setViewPropertiesContext(const QString& context);
+    QString viewPropertiesContext() const;
+
 public slots:
     /**
      * Changes the directory to \a url. If the current directory is equal to
@@ -450,17 +403,20 @@ signals:
     void groupedSortingChanged(bool groupedSorting);
 
     /** Is emitted if the sorting by name, size or date has been changed. */
-    void sortingChanged(DolphinView::Sorting sorting);
+    void sortRoleChanged(const QByteArray& role);
 
     /** Is emitted if the sort order (ascending or descending) has been changed. */
     void sortOrderChanged(Qt::SortOrder order);
 
-    /** Is emitted if the sorting of files and folders (separate with folders first or mixed) has been changed. */
+    /**
+     * Is emitted if the sorting of files and folders (separate with folders
+     * first or mixed) has been changed.
+     */
     void sortFoldersFirstChanged(bool foldersFirst);
 
     /** Is emitted if the additional information shown for this view has been changed. */
-    void additionalInfoListChanged(const QList<DolphinView::AdditionalInfo>& current,
-                                   const QList<DolphinView::AdditionalInfo>& previous);
+    void visibleRolesChanged(const QList<QByteArray>& current,
+                             const QList<QByteArray>& previous);
 
     /** Is emitted if the zoom level has been changed by zooming in or out. */
     void zoomLevelChanged(int current, int previous);
@@ -507,32 +463,32 @@ signals:
 
     /**
      * Is emitted after DolphinView::setUrl() has been invoked and
-     * the path \a url is currently loaded. If this signal is emitted,
+     * the current directory is loaded. If this signal is emitted,
      * it is assured that the view contains already the correct root
      * URL and property settings.
      */
-    void startedPathLoading(const KUrl& url);
+    void directoryLoadingStarted();
 
     /**
-     * Is emitted after the path triggered by DolphinView::setUrl()
+     * Is emitted after the directory triggered by DolphinView::setUrl()
      * has been loaded.
      */
-    void finishedPathLoading(const KUrl& url);
+    void directoryLoadingCompleted();
 
     /**
      * Is emitted after DolphinView::setUrl() has been invoked and provides
-     * the information how much percent of the current path have been loaded.
+     * the information how much percent of the current directory have been loaded.
      */
-    void pathLoadingProgress(int percent);
+    void directoryLoadingProgress(int percent);
 
     /**
-     * Is emitted if the DolphinView::setUrl() is invoked but the URL is not
-     * a directory.
+     * Is emitted if the sorting is done asynchronously and provides the
+     * progress information of the sorting.
      */
-    void urlIsFileError(const KUrl& file);
+    void directorySortingProgress(int percent);
 
     /**
-     * Emitted when KDirLister emits redirection.
+     * Emitted when the file-item-model emits redirection.
      * Testcase: fish://localhost
      */
     void redirection(const KUrl& oldUrl, const KUrl& newUrl);
@@ -544,6 +500,18 @@ signals:
      */
     void writeStateChanged(bool isFolderWritable);
 
+    /**
+     * Is emitted if the URL should be changed to the previous URL of the
+     * history (e.g. because the "back"-mousebutton has been pressed).
+     */
+    void goBackRequested();
+
+    /**
+     * Is emitted if the URL should be changed to the next URL of the
+     * history (e.g. because the "next"-mousebutton has been pressed).
+     */
+    void goForwardRequested();
+
 protected:
     /** Changes the zoom level if Control is pressed during a wheel event. */
     virtual void wheelEvent(QWheelEvent* event);
@@ -564,10 +532,12 @@ private slots:
     void slotItemContextMenuRequested(int index, const QPointF& pos);
     void slotViewContextMenuRequested(const QPointF& pos);
     void slotHeaderContextMenuRequested(const QPointF& pos);
+    void slotHeaderColumnWidthChanged(const QByteArray& role, qreal current, qreal previous);
     void slotItemHovered(int index);
     void slotItemUnhovered(int index);
     void slotItemDropEvent(int index, QGraphicsSceneDragDropEvent* event);
     void slotModelChanged(KItemModelBase* current, KItemModelBase* previous);
+    void slotMouseButtonPressed(int itemIndex, Qt::MouseButtons buttons);
 
     /**
      * Emits the signal \a selectionChanged() with a small delay. This is
@@ -586,9 +556,9 @@ private slots:
 
     /**
      * Updates the view properties of the current URL to the
-     * sorting given by \a sorting.
+     * sorting given by \a role.
      */
-    void updateSorting(DolphinView::Sorting sorting);
+    void updateSortRole(const QByteArray& role);
 
     /**
      * Updates the view properties of the current URL to the
@@ -623,23 +593,21 @@ private slots:
     void slotDeleteFileFinished(KJob* job);
 
     /**
-     * Invoked when the directory lister has been started the
-     * loading of \a url.
+     * Invoked when the file item model has started the loading
+     * of the directory specified by DolphinView::url().
      */
-    void slotDirListerStarted(const KUrl& url);
+    void slotDirectoryLoadingStarted();
 
     /**
-     * Invoked when the file item model indicates that the directory lister has completed the loading
-     * of items, and that expanded folders have been restored (if the view mode is 'Details', and the
-     * view state is restored after navigating back or forward in history). Assures that pasted items
-     * and renamed items get seleced.
+     * Invoked when the file item model indicates that the loading of a directory has
+     * been completed. Assures that pasted items and renamed items get seleced.
      */
-    void slotLoadingCompleted();
+    void slotDirectoryLoadingCompleted();
 
     /**
-     * Is invoked when the KDirLister indicates refreshed items.
+     * Is invoked when items of KFileItemModel have been changed.
      */
-    void slotRefreshItems();
+    void slotItemsChanged();
 
     /**
      * Is invoked when the sort order has been changed by the user by clicking
@@ -660,6 +628,8 @@ private slots:
     void slotVisibleRolesChangedByHeader(const QList<QByteArray>& current,
                                          const QList<QByteArray>& previous);
 
+    void slotRoleEditingFinished(int index, const QByteArray& role, const QVariant& value);
+
     /**
      * Observes the item with the URL \a url. As soon as the directory
      * model indicates that the item is available, the item will
@@ -679,7 +649,7 @@ private slots:
      * Called when a redirection happens.
      * Testcase: fish://localhost
      */
-    void slotRedirection(const KUrl& oldUrl, const KUrl& newUrl);
+    void slotDirectoryRedirection(const KUrl& oldUrl, const KUrl& newUrl);
 
     /**
      * Applies the state that has been restored by restoreViewState()
@@ -689,11 +659,17 @@ private slots:
 
     void hideToolTip();
 
-    //void slotUrlChangeRequested(const KUrl& url);
+    /**
+     * Calculates the number of currently shown files into
+     * \a fileCount and the number of folders into \a folderCount.
+     * The size of all files is written into \a totalFileSize.
+     * It is recommend using this method instead of asking the
+     * directory lister or the model directly, as it takes
+     * filtering and hierarchical previews into account.
+     */
+    void calculateItemCount(int& fileCount, int& folderCount, KIO::filesize_t& totalFileSize) const;
 
 private:
-    KFileItemModel* fileItemModel() const;
-
     void loadDirectory(const KUrl& url, bool reload = false);
 
     /**
@@ -702,7 +678,11 @@ private:
      */
     void applyViewProperties();
 
-    void applyAdditionalInfoListToView();
+    /**
+     * Applies the m_mode property to the corresponding
+     * itemlayout-property of the KItemListView.
+     */
+    void applyModeToView();
 
     /**
      * Helper method for DolphinView::paste() and DolphinView::pasteIntoFolder().
@@ -737,8 +717,12 @@ private:
      */
     void updateWritableState();
 
-    QByteArray sortRoleForSorting(Sorting sorting) const;
-    Sorting sortingForSortRole(const QByteArray& sortRole) const;
+    /**
+     * @return The current URL if no viewproperties-context is given (see
+     *         DolphinView::viewPropertiesContext(), otherwise the context
+     *         is returned.
+     */
+    KUrl viewPropertiesUrl() const;
 
 private:
     bool m_active;
@@ -749,13 +733,15 @@ private:
                      // tooltip may be shown when hovering an item.
 
     KUrl m_url;
+    QString m_viewPropertiesContext;
     Mode m_mode;
-    QList<AdditionalInfo> m_additionalInfoList;
+    QList<QByteArray> m_visibleRoles;
 
     QVBoxLayout* m_topLayout;
 
-    DolphinDirLister* m_dirLister;
-    DolphinItemListContainer* m_container;
+    KFileItemModel* m_model;
+    DolphinItemListView* m_view;
+    KItemListContainer* m_container;
 
     ToolTipManager* m_toolTipManager;
 
