@@ -37,9 +37,10 @@
 #include <kcolordialog.h>
 #include <kwindowsystem.h>
 #include <kiconloader.h>
+#include <klocale.h>
 
 #include <QtCore/QTimer>
-#include <QtGui/QDesktopWidget>
+#include <QDesktopWidget>
 
 #include <iostream>
 
@@ -54,7 +55,7 @@
 #endif
 
 #ifdef Q_WS_WIN
-#include <QtGui/QFileDialog>
+#include <QFileDialog>
 #endif
 #include <unistd.h>
 
@@ -738,8 +739,11 @@ static int directCommand(KCmdLineArgs *args)
 	KIconDialog dlg((QWidget*)0L);
 	kapp->setTopWidget( &dlg );
 	dlg.setup( group, context);
+        dlg.setIconSize(KIconLoader::SizeHuge);
+
 	if (!title.isEmpty())
 	    dlg.setCaption(title);
+
 	Widgets::handleXGeometry(&dlg);
 
 	QString result = dlg.openDialog();
@@ -843,7 +847,6 @@ int main(int argc, char *argv[])
   aboutData.addAuthor(ki18n("Kai Uwe Broulik"),KLocalizedString(),"kde@privat.broulik.de");
   aboutData.setProgramIconName("system-run");
 
-
   KCmdLineArgs::init(argc, argv, &aboutData);
 
   KCmdLineOptions options;
